summaryrefslogtreecommitdiffstats
path: root/configdialog/kbfxconfigdlgabout.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'configdialog/kbfxconfigdlgabout.ui.h')
-rw-r--r--configdialog/kbfxconfigdlgabout.ui.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/configdialog/kbfxconfigdlgabout.ui.h b/configdialog/kbfxconfigdlgabout.ui.h
index 7f4b739..fa31f83 100644
--- a/configdialog/kbfxconfigdlgabout.ui.h
+++ b/configdialog/kbfxconfigdlgabout.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
@@ -51,7 +51,7 @@ void KbfxConfigDlgAbout::init()
"<br><br>"
"<strong>Country:</strong> Bulgaria"
"<br><br>"
- "<strong>KBFX:</strong> package & release manager, Q/A, bug hunter, mandriva packages, project administrator, developer Qt/C++"
+ "<strong>KBFX:</strong> package & release manager, Q/A, bug hunter, mandriva packages, project administrator, developer TQt/C++"
"<br><br>"
"<strong>Email:</strong> phobosk@mail.kbfx.org" );
@@ -60,7 +60,7 @@ void KbfxConfigDlgAbout::init()
"<br><br>"
"<strong>Country:</strong> Peru"
"<br><br>"
- "<strong>KBFX:</strong> developer Qt4/C++"
+ "<strong>KBFX:</strong> developer TQt4/C++"
"<br><br>"
"<strong>Email:</strong> saenzac@mail.kbfx.org" );
@@ -74,60 +74,60 @@ void KbfxConfigDlgAbout::init()
"<strong>Email:</strong> ephracis@mail.kbfx.org" );
}
-bool KbfxConfigDlgAbout::eventFilter ( QObject *obj, QEvent *ev )
+bool KbfxConfigDlgAbout::eventFilter ( TQObject *obj, TQEvent *ev )
{
- QCursor kbfxCursor;
+ TQCursor kbfxCursor;
kbfxCursor.setShape ( Qt::PointingHandCursor );
- this->setCursor ( ( const QCursor ) kbfxCursor );
+ this->setCursor ( ( const TQCursor ) kbfxCursor );
- if ( ev->type() == QEvent::FocusIn || ev->type() == QEvent::Enter )
+ if ( ev->type() == TQEvent::FocusIn || ev->type() == TQEvent::Enter )
{
- if ( obj == KbfxPixmapLabelNookie )
+ if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNookie) )
{
KbfxTeamInfo->setText ( KbfxMemberTextNookie );
KbfxUnmarkAllPixmaps();
- KbfxPixmapLabelNookie->setFrameShape ( QFrame::WinPanel );
+ KbfxPixmapLabelNookie->setFrameShape ( TQFrame::WinPanel );
return TRUE;
}
- else if ( obj == KbfxPixmapLabelSiraj )
+ else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelSiraj) )
{
KbfxTeamInfo->setText ( KbfxMemberTextSiraj );
KbfxUnmarkAllPixmaps();
- KbfxPixmapLabelSiraj->setFrameShape ( QFrame::WinPanel );
+ KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::WinPanel );
return TRUE;
}
- else if ( obj == KbfxPixmapLabelNathanael )
+ else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNathanael) )
{
KbfxTeamInfo->setText ( KbfxMemberTextNathanael );
KbfxUnmarkAllPixmaps();
- KbfxPixmapLabelNathanael->setFrameShape ( QFrame::WinPanel );
+ KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::WinPanel );
return TRUE;
}
- else if ( obj == KbfxPixmapLabelPhobosK )
+ else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelPhobosK) )
{
KbfxTeamInfo->setText ( KbfxMemberTextPhobosK );
KbfxUnmarkAllPixmaps();
- KbfxPixmapLabelPhobosK->setFrameShape ( QFrame::WinPanel );
+ KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::WinPanel );
return TRUE;
}
- else if ( obj == KbfxPixmapLabelJohnny )
+ else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelJohnny) )
{
KbfxTeamInfo->setText ( KbfxMemberTextJohnny );
KbfxUnmarkAllPixmaps();
- KbfxPixmapLabelJohnny->setFrameShape ( QFrame::WinPanel );
+ KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::WinPanel );
return TRUE;
}
- else if ( obj == KbfxPixmapLabelEphracis )
+ else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelEphracis) )
{
KbfxTeamInfo->setText ( KbfxMemberTextEphracis );
KbfxUnmarkAllPixmaps();
- KbfxPixmapLabelEphracis->setFrameShape ( QFrame::WinPanel );
+ KbfxPixmapLabelEphracis->setFrameShape ( TQFrame::WinPanel );
return TRUE;
}
}
/*
- if ( ev->type() == QEvent::Leave )
+ if ( ev->type() == TQEvent::Leave )
{
if(
obj == KbfxPixmapLabelNookie ||
@@ -144,16 +144,16 @@ bool KbfxConfigDlgAbout::eventFilter ( QObject *obj, QEvent *ev )
}
*/
- return QWidget::eventFilter ( obj, ev );
+ return TQWidget::eventFilter ( obj, ev );
// return FALSE;
}
void KbfxConfigDlgAbout::KbfxUnmarkAllPixmaps()
{
- KbfxPixmapLabelNookie->setFrameShape ( QFrame::NoFrame );
- KbfxPixmapLabelSiraj->setFrameShape ( QFrame::NoFrame );
- KbfxPixmapLabelNathanael->setFrameShape ( QFrame::NoFrame );
- KbfxPixmapLabelPhobosK->setFrameShape ( QFrame::NoFrame );
- KbfxPixmapLabelEphracis->setFrameShape ( QFrame::NoFrame );
- KbfxPixmapLabelJohnny->setFrameShape ( QFrame::NoFrame );
+ KbfxPixmapLabelNookie->setFrameShape ( TQFrame::NoFrame );
+ KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::NoFrame );
+ KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::NoFrame );
+ KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::NoFrame );
+ KbfxPixmapLabelEphracis->setFrameShape ( TQFrame::NoFrame );
+ KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::NoFrame );
}
@@ -2,7 +2,7 @@
**
** If you want to add, delete, or rename functions or slots, use
-** Qt Designer to update this file, preserving your code.
+** TQt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.